Blaster

Struct Blaster 

pub struct Blaster<'a, B: UsbBus, E, TDI: OutputPin<Error = E>, TCK: OutputPin<Error = E>, TMS: OutputPin<Error = E>, TDO: InputPin<Error = E>> { /* private fields */ }
Blaster device class

Implementations

Source

impl<'a, B: UsbBus, E, TDI: OutputPin<Error = E>, TCK: OutputPin<Error = E>, TMS: OutputPin<Error = E>, TDO: InputPin<Error = E>> Blaster<'a, B, E, TDI, TCK, TMS, TDO>

pub fn new( alloc: &'a UsbBusAllocator<B>, tdi: TDI, tck: TCK, tms: TMS, tdo: TDO, ) -> Blaster<'a, B, E, TDI, TCK, TMS, TDO>

Allocate a Blaster on the USB bus. Takes control of the four JTAG pins. The JTAG pins can be any pins you want, just make sure you assign them correctly.

pub fn read(&mut self) -> Result<usize>

Read data from the host output endpoint into the Blaster’s internal read buffer.

pub fn write(&mut self, heartbeat: bool) -> Result<usize>

Write data to the host input endpoint from the Blaster’s internal write buffer. The heartbeat parameter must be true at least once every 10 milliseconds, so that the blaster can output the modem status. See libftdi ftdi.c for more on this. Otherwise, a BSOD could occur on Windows A safe default for the heartbeat seems to be true all the time. This will output the modem status whenever the host reads the device.

pub fn handle(&mut self) -> Result<(), E>

Runs all pending operations from the internal read buffer until either no operations are left or the internal write buffer is full. If a GPIO error occurs, the JTAG state machine will enter an undefined state requiring a forced USB bus reset.