pub struct Blaster<'a, B: UsbBus, E, TDI: OutputPin<Error = E>, TCK: OutputPin<Error = E>, TMS: OutputPin<Error = E>, TDO: InputPin<Error = E>> { /* private fields */ }Expand description
Blaster device class
Implementations
Sourceimpl<'a, B: UsbBus, E, TDI: OutputPin<Error = E>, TCK: OutputPin<Error = E>, TMS: OutputPin<Error = E>, TDO: InputPin<Error = E>> Blaster<'a, B, E, TDI, TCK, TMS, TDO>
impl<'a, B: UsbBus, E, TDI: OutputPin<Error = E>, TCK: OutputPin<Error = E>, TMS: OutputPin<Error = E>, TDO: InputPin<Error = E>> Blaster<'a, B, E, TDI, TCK, TMS, TDO>
Sourcepub fn new(
alloc: &'a UsbBusAllocator<B>,
tdi: TDI,
tck: TCK,
tms: TMS,
tdo: TDO,
) -> Blaster<'a, B, E, TDI, TCK, TMS, TDO>
pub fn new( alloc: &'a UsbBusAllocator<B>, tdi: TDI, tck: TCK, tms: TMS, tdo: TDO, ) -> Blaster<'a, B, E, TDI, TCK, TMS, TDO>
Allocate a Blaster on the USB bus. Takes control of the four JTAG pins. The JTAG pins can be any pins you want, just make sure you assign them correctly.
Sourcepub fn read(&mut self) -> Result<usize>
pub fn read(&mut self) -> Result<usize>
Read data from the host output endpoint into the Blaster’s internal read buffer.
Sourcepub fn write(&mut self, heartbeat: bool) -> Result<usize>
pub fn write(&mut self, heartbeat: bool) -> Result<usize>
Write data to the host input endpoint from the Blaster’s internal write buffer. The heartbeat parameter must be true at least once every 10 milliseconds, so that the blaster can output the modem status. See libftdi ftdi.c for more on this. Otherwise, a BSOD could occur on Windows A safe default for the heartbeat seems to be true all the time. This will output the modem status whenever the host reads the device.